<?php

/**
 * Main class.
 *
 * @since      	1.1.0
 * @author     	Pulido Pereira Nuno Ricardo <pereira@nunoapps.com>
 * @copyright  	Copyright (c) 2007 - 2013, Pulido Pereira Nuno Ricardo
 * @link       	http://nunoapps.com/plugins/facebook-opengraph-meta
 * @license   	http://www.gnu.org/licenses/gpl-2.0.html
 */

class NunoApps_FacebookOpenGraphMeta extends NunoApps_Plugin {

	public function init() {

		/* Add opengraph meta in language attributes. */
		add_filter( 'language_attributes', array( $this, 'add_opengraph_meta' ) );

		/* Add Facebook header on wordpress head. */
		add_action( 'wp_head', array( $this, 'insert_facebook_headers' ) );

	}

	/**
	 * Add admin menu.
	 */
	public static function admin_menu() {

		$menu_atts = array(
			'type'			=> 'option',
			'page_title'	=> __( 'Facebook OpenGraph Meta - Settings', 'facebook-opengraph-meta' ),
			'menu_title'	=> __( 'Facebook OpenGraph Meta', 'facebook-opengraph-meta' ),
			'box_data'		=> array(
				'plugin'	=> NunoApps_FacebookOpenGraphMeta::get_plugin_data(),
				'settings'	=> NunoApps_FacebookOpenGraphMeta_Settings::get_all()
			)
		);

		NunoApps_FacebookOpenGraphMeta_Settings_Page::register( $menu_atts );
	}

	/**
	 * Add open graph meta in head.
	 *
	 * @since 	0.0.1
	 * @access 	public
	 * @param 	string
	 * @return 	string
	 */
	public function add_opengraph_meta( $output ) {

		return $output . ' xmlns:og="http://opengraphprotocol.org/schema/" xmlns:fb="http://www.facebook.com/2008/fbml"';

	}

	/**
	 * Insert HTML code in head page.
	 *
	 * @since 	0.0.1
	 * @access 	public
	 * @return 	void
	 */
	public function insert_facebook_headers() {

		global $post;

		/* Get plugin settings. */
		//$settings = get_option( 'facebook_opengraph_meta_settings' );
		$settings = NunoApps_FacebookOpenGraphMeta_Settings::get_all();

		echo "\n" . '<!-- Facebook OpenGraph Meta http://nunoapps.com/plugins/facebook-opengraph-meta -->' . "\n";

		/* If setting facebook admin username print it. */
		if ( $settings['facebook_admin_id'] )
			echo '<meta property="fb:admins" content="' . $settings['facebook_admin_id'] . '" />' . "\n";

		/* Print locale property. */
		if ( defined( WPLANG ) and ! WPLANG )
			echo '<meta property="og:locale" content="' . WPLANG . '" />' . "\n";
		else
			echo '<meta property="og:locale" content="en_US" />' . "\n";
	
		if ( is_singular() ) {

			echo '<meta property="og:type" content="article"/>' . "\n";
			echo '<meta property="og:title" content="' . get_the_title() . '" />' . "\n";
			echo '<meta property="og:url" content="' . get_permalink() . '" />' . "\n";

			if ( ! has_post_thumbnail( $post->ID ) ) {
		
				if ( $settings['thumbnail_default_url'] )
					echo '<meta property="og:image" content="' . $settings['thumbnail_default_url'] . '"/>' . "\n";
			
			} else {

				$thumbnail_src = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), $settings['thumbnail_size'] );

				echo '<meta property="og:image" content="' . esc_attr( $thumbnail_src[0] ) . '"/>' . "\n";
			}

		} elseif ( is_home() ) {

			/* Print type property. */
			echo '<meta property="og:type" content="website"/>' . "\n";

			if ( $settings['thumbnail_default_url'] )
				echo '<meta property="og:image" content="' . $settings['thumbnail_default_url'] . '"/>' . "\n";

			echo '<meta property="og:title" content="' . get_option( 'blogname' ) . ' | ' . get_option( 'blogdescription' ) . '" />' . "\n";
			echo '<meta property="og:url" content="' . get_home_url() . '" />' . "\n";

		}
	
		echo '<meta property="og:site_name" content="' . get_option( 'blogname' ) . '" />' . "\n";

		

		echo '<!-- / Facebook OpenGraph Meta http://nunoapps.com/plugins/facebook-opengraph-meta -->' . "\n\n";

	}

}