<?php

class NunoApps_FacebookOpenGraphMeta_Settings_Page extends NunoApps_Settings_Page {
	
	static $token = 'facebook-opengraph-meta';

	public static function add_meta_boxes() {

		/* Add the 'General' meta box. */
		add_meta_box( 'facebook-opengraph-meta-general', _x( 'General Settings', 'meta box', 'facebook-opengraph-meta' ), array( __CLASS__, 'meta_box_general' ), 'facebook-opengraph-meta-settings', 'normal', 'high' );

	}

	public static function validate_settings( $settings ) {

		$settings['facebook_admin_id'] 		= strip_tags( $settings['facebook_admin_id'] );
		$settings['thumbnail_default_url'] 	= strip_tags( $settings['thumbnail_default_url'] );
		$settings['thumbnail_size']			= strip_tags( $settings['thumbnail_size'] );

		/* Kill evil scripts. */
		if ( ! current_user_can( 'unfiltered_html' ) ) {

			$settings['facebook_admin_id'] 		= stripslashes( wp_filter_post_kses( addslashes( $settings['facebook_admin_id'] ) ) );
			$settings['thumbnail_default_url'] 	= stripslashes( wp_filter_post_kses( addslashes( $settings['thumbnail_default_url'] ) ) );
			$settings['thumbnail_size'] 		= stripslashes( wp_filter_post_kses( addslashes( $settings['thumbnail_size'] ) ) );
		
		}			

		/* Return the validated/sanitized settings. */
		return $settings;

	}

	public static function meta_box_general( $object, $box ) { ?>

		<table class="form-table">
		
			<tr scope="row">
				<th><label for="facebook_opengraph_meta_settings-facebook_admin_id"><?php _e( 'Facebook Admin ID:', 'facebook-opengraph-meta' ); ?></label></th>
				<td>
					<input type="text" class="regular-text" name="facebook_opengraph_meta_settings[facebook_admin_id]" id="facebook_opengraph_meta_settings-facebook_admin_id" value="<?php echo esc_attr( $object['settings']['facebook_admin_id'] ); ?>" />
					<p class="description"><?php _e( 'Enter your facebook admin id.', 'facebook-opengraph-meta' ); ?></p>
				</td>	
			</tr>

			<tr scope="row">
				<th><label for="facebook_opengraph_meta_settings-thumbnail_default_url"><?php _e( 'Default image thumbnail URL:', 'facebook-opengraph-meta' ); ?></label></th>
				<td>
					<input type="text" class="regular-text" name="facebook_opengraph_meta_settings[thumbnail_defaul_url]" id="facebook_opengraph_meta_settings-thumbnail_default_url" value="<?php echo esc_attr( $object['settings']['thumbnail_default_url'] ); ?>" />
					<p class="description"><?php _e( 'Choose your image URL for Open Graph Meta.', 'facebook-opengraph-meta' ); ?></p>
				</td>
			</tr>

			<tr scope="row">
				<th><label for="facebook_opengraph_meta_settings-thumbnail_size"><?php _e( 'Thumbnail image size:', 'facebook-opengraph-meta' ); ?></label></th>
				<td>
					<select id="facebook_opengraph_meta_settings-thumbnail_size" name="facebook_opengraph_meta_settings[thumbnail_size]">

						<?php foreach ( get_intermediate_image_sizes() as $thumbnail_size ) : ?>

							<option value="<?php echo $thumbnail_size; ?>" <?php selected( $object['settings']['thumbnail_size'], $thumbnail_size ); ?> ><?php echo $thumbnail_size; ?></option>

						<?php endforeach; ?>

					</select>
					<p class="description"><?php _e( 'Select the thumbnail size.', 'facebook-opengraph-meta' ); ?></p>
				</td>
			</tr>

		</table>

	<?php }
}