<?php



abstract class NunoApps_Plugin {

	/**
	 * Full path of current plugin
	 *
	 * @var string
	 */
	protected $_plugin_path;

	/**
	 * WordPress plugin basename
	 *
	 * @var string
	 */
	protected $_plugin_basename;

	/**
	 * Full path to the plugin root directory
	 *
	 * @var string
	 */
	protected $_plugin_dir;

	/**
	 * Full URI of plugin root directory
	 *
	 * @var string
	 */
	protected $_plugin_uri;
	
	/**
	 * Disable construction.
	 */
	protected function __construct() {}

	/**
	 * Disable cloning.
	 */
	final private function __clone() {}

	final protected static function get_instance() {

		static $i;

		$c = get_called_class();

		if ( ! isset( $i[ $c ] ) ) {

			$plugin_initializer = $c::get_run_file();
			if ( ! $plugin_initializer ) {
				return trigger_error( __( sprintf( 'Plugin is not initialized correctly. Please initalize plugin trough "%s::run" first.', $c ), 'nunocore' ), E_USER_ERROR );
			}

			$i[ $c ] = new $c;

			// Define basic variables
			$i[ $c ]->_plugin_path 		= $plugin_initializer;
			$i[ $c ]->_plugin_dir 		= dirname( $i[ $c ]->_plugin_path );
			$i[ $c ]->_plugin_uri 		= plugin_dir_url( $i[ $c ]->_plugin_path );
			$i[ $c ]->_plugin_basename 	= dirname( plugin_basename( $i[ $c ]->_plugin_path ) );

			// Basic hooks.
			add_action( 'plugins_loaded', $c . '::add_basic_actions_and_filters' );

			// Admin Menu.
			if ( method_exists( $c, 'admin_menu' ) )
				add_action( 'admin_menu', $c . '::admin_menu' );

			// Init plugin.
			$i[ $c ]->init();

		}

		return $i[ $c ];
	}

	final public static function add_basic_actions_and_filters() {

		$class 		= get_called_class();
		$instance 	= $class::get_instance();

		// Load framework translations.
		load_plugin_textdomain( 'nunoapps-plugin', false, 'nunoapps-plugin/languages/' );

		// Load plugin translations.
		load_plugin_textdomain( $instance->_plugin_basename, false, $instance->_plugin_basename . '/languages/' );

	}

	final public static function i18n( $domain, $path = null ) {

		if ( null === $path )
			$path = $instance->_plugin_dir . '/languages/';

		load_plugin_textdomain( $domain, false, $path );

	}

	final public static function get_plugin_data() {

		$class = get_called_class();
		$instance = $class::get_instance();

		return get_plugin_data( $instance->_plugin_path );
	}

	final public static function get_URI() {

		$class = get_called_class();
		$instance = $class::get_instance();

		return $instance->_plugin_uri;
	}

	final public static function get_version() {

		$class = get_called_class();
		$instance = $class::get_instance();

		return $instance::version;
	}

	/**
	 * Init Plugin
	 */
	abstract protected function init();

	/**
	 * Retrieves name of file where plugin hook is called.
	 */
	final protected static function get_run_file() {
		
		foreach ( debug_backtrace() as $item ) {
			if ( isset( $item['class'] ) && isset( $item['function'] ) ) {
				if ( __CLASS__ === $item['class'] && 'run' === $item['function'] ) {
					return $item['file'];
					//return basename( plugin_dir_path( $item ['file'] ) );
				}
			}
		}

		return false;
	}

	/**
	 * Initializes and setups plugin.
	 *
	 * Should be called from WordPress plugin definition file.
	 */
	final public static function run() {
		$class = get_called_class();
		return $class::get_instance();
	}

}