<?php

abstract class NunoApps_Settings_Page extends NunoApps_Singleton {

	protected static $token;
	
	protected static $_page;

	protected static $_attributes;

	public static function register( $atts ) {

		// Validate atts.
		if ( ! is_array( $atts ) )
			return;

		// Create instance.
		$instance = self::get_instance();

		$defaul_atts = array(

			'page_title'	=> '',

			'menu_title'	=> '',

			'type'	=> 'option',
			
			'box_data'	=> array(
				'plugin'	=> array(),
				'settings'	=> array()
			),

			'capability'	=> apply_filters( $instance::$token . '_settings_capability', 'manage_options' ),

			'position'	=> null,

			'settings_id'	=> str_replace( '-', '_', $instance::$token ) . '_settings',

			'callback'	=> array( $instance, 'render' ),

			'icon_url'	=> false,

			'menu_slug'	=> $instance::$token . '-settings'
		);

		$instance::$_attributes = array_merge( $defaul_atts, $atts );

		switch ( $instance::$_attributes['type'] ) {

			case 'option':
				$instance::$_page = add_options_page(
					$instance::$_attributes['page_title'],
					$instance::$_attributes['menu_title'],
					$instance::$_attributes['capability'],
					$instance::$_attributes['menu_slug'],
					$instance::$_attributes['callback']
				);
			break;

			case 'page':
				$instance::$_page = add_menu_page(
					$instance::$_attributes['page_title'],
					$instance::$_attributes['menu_title'],
					$instance::$_attributes['capability'],
					$instance::$_attributes['menu_slug'],
					$instance::$_attributes['callback'],
					$instance::$_attributes['icon_url'],
					$instance::$_attributes['position']
				);
			break;

			default:
				return false;
			break;
		}

		if ( ! empty( $instance::$_page ) ) {

			/* Register the plugin settings. */
			add_action( 'admin_init', array( $instance, 'register_settings' ) );

			/* Add media for the settings page. */
			add_action( 'admin_enqueue_scripts', array( $instance, 'enqueue_scripts' ) );
			add_action( 'admin_head-' . $instance::$_page, array( $instance, 'print_admin_head' ) );

			// Add default meta boxes.
			add_action( 'add_meta_boxes', array( $instance, 'add_default_meta_boxes' ) );

			/* Load the meta boxes. */
			add_action( 'add_meta_boxes_' . $instance::$token, array( $instance, 'add_meta_boxes' ) );

		}

	}

	public static function add_separator( $position ) {

		global $menu;
	
		$index = 0;
		
		foreach ( $menu as $offset => $section ) {
			
			if ( 'separator' === substr( $section[2], 0, 9 ) )
				$index++;
		
			if ( $offset >= $position ) {

				$menu[ $position ] = array( '','read', "separator{$index}", '', 'wp-menu-separator' );
				break;
			
			}

		}

		ksort( $menu );

	}

	public static function register_settings() {

		$instance = self::get_instance();

		register_setting( $instance::$_attributes['menu_slug'], $instance::$_attributes['settings_id'], array( $instance, 'validate_settings' ) );

	}

	public static function validate_settings( $settings ) {
		return $settings;
	}

	public static function add_default_meta_boxes() {

		$instance = self::get_instance();

		/* Add the 'About' meta box. */
		add_meta_box( $instance::$_attributes['menu_slug'] . '-about', _x( 'About', 'meta box', 'nunoapps-plugin' ), array( $instance, 'meta_box_about' ), $instance::$_attributes['menu_slug'], 'side', 'high' );

		/* Add the 'Donate' meta box. */
		add_meta_box( $instance::$_attributes['menu_slug'] . '-donate', _x( 'Like this plugin?', 'meta box', 'nunoapps-plugin' ), array( $instance, 'meta_box_donate' ), $instance::$_attributes['menu_slug'], 'side', 'default' );

		/* Add the 'Support' meta box. */
		add_meta_box( $instance::$_attributes['menu_slug'] . '-support', _x( 'Support', 'meta box', 'nunoapps-plugin' ), array( $instance, 'meta_box_support' ), $instance::$_attributes['menu_slug'], 'side', 'low' );

	}

	public static function add_meta_boxes() {}

	public static function meta_box_about( $object, $box ) { ?>

		<p>
			<strong><?php _e( 'Version:', 'nunoapps-plugin' ); ?></strong> 
			<?php echo $object['plugin']['Version']; ?>
		</p>
		
		<p>
			<strong><?php _e( 'Description:', 'nunoapps-plugin' ); ?></strong> 
			<?php echo $object['plugin']['Description']; ?>
		</p>

	<?php }

	public static function meta_box_donate( $object, $box ) { ?>

		<div>
			<p><?php _e( "Here's how you can give back:", 'nunoapps-plugin' ); ?></p>

			<ul>
				<li><a href="http://wordpress.org/extend/plugins/<?php echo $object['plugin']['TextDomain']; ?>" title="<?php esc_attr_e( 'See plugin on the WordPress plugin repository', 'nunoapps-plugin' ); ?>"><?php _e( 'Give the plugin a good rating.', 'nunoapps-plugin' ); ?></a></li>
			</ul>
		</div>

	<?php }

	public static function meta_box_support( $object, $box ) { ?>
	
		<p>
			<?php printf( __( 'Support for this plugin is provided via the our site at %s. If you need any help using it, please ask your support questions there.', 'nunoapps-plugin' ), '<a href="http://nunoapps.com/" title="' . esc_attr__( 'NunoApps Support', 'nunoapps-plugin' ) . '">' . __( 'NunoApps', 'nunoapps-plugin' ) . '</a>' ); ?>
		</p>

	<?php }

	public static function render() {

		$instance = self::get_instance();

		do_action( 'add_meta_boxes', $instance::$_attributes['menu_slug'], $instance::$_attributes['box_data'] );
		do_action( 'add_meta_boxes_' . $instance::$token, $instance::$_attributes['menu_slug'], $instance::$_attributes['box_data'] );

		?>
		<div class="wrap">

			<?php screen_icon(); ?>

			<h2><?php echo $instance::$_attributes['page_title']; ?></h2>

			<?php //settings_errors(); ?>

			<form method="post" action="options.php">

				<div id="poststuff">

					<?php settings_fields( $instance::$_attributes['menu_slug'] ); ?>
					<?php wp_nonce_field( 'closedpostboxes', 'closedpostboxesnonce', false ); ?>
					<?php wp_nonce_field( 'meta-box-order', 'meta-box-order-nonce', false ); ?>

					<div id="post-body" class="metabox-holder columns-2">

						<div id="post-body-content">
							<?php do_meta_boxes( $instance::$_attributes['menu_slug'], 'normal', $instance::$_attributes['box_data'] ); ?>
						</div><!-- .post-body-content -->

						<div id="postbox-container-1" class="postbox-container">
							<?php do_meta_boxes( $instance::$_attributes['menu_slug'], 'side', $instance::$_attributes['box_data'] ); ?>
						</div><!-- #post-container-1 .postbox-container -->

						

					</div><!-- #post-body -->

					<br class="clear" />

					<?php submit_button( esc_attr__( 'Update Settings', 'nunoapps-plugin' ) ); ?>

				</div><!-- #poststuff -->

				<input type="hidden" name="<?php echo $instance::$_attributes['menu_slug']; ?>_nonce" value="<?php echo $instance::$_attributes['menu_slug']; ?>_nonce" />

			</form>

		</div><!-- .wrap --><?php

	}

	public static function enqueue_scripts( $hook_suffix ) {

		$instance = self::get_instance();

		if ( $hook_suffix == $instance::$_page ) {
		
			wp_enqueue_script( 'common' );
			wp_enqueue_script( 'wp-lists' );
			wp_enqueue_script( 'postbox' );
		
		}

	}

	public static function print_admin_head() {

		$instance = self::get_instance(); ?>

		<script type="text/javascript">
			//<![CDATA[
			jQuery(document).ready(function($) {
				$( '.if-js-closed' ).removeClass( 'if-js-closed' ).addClass( 'closed' );
				postboxes.add_postbox_toggles( '<?php echo $instance::$_page; ?>' );
			});
			//]]>
		</script>

		<style>
			/* Plugin settings page. */
			.form-table th {
			        width: 30%;
			        font-weight: bold;
			        }
			.metabox-holder .column-1 {
			        float: left;
			        width: 66%;
			        }
			.metabox-holder .column-2 {
			        float: right;
			        width: 32%;
			        }
			.hook-editor {
			        overflow: hidden;
			        }
			p.submit {
			        clear: both;
			        }
			.postbox .inside p, 
			.postbox .inside li {
			        }
			.postbox form {
			        line-height: 150%;        
			        }
			div.inside ul {
			        margin-left: 20px;
			        }
			div.inside ul li {
			        list-style: square;
			        line-height:16px;
			        }
			div.inside .alignleft {
			        width: 45%;
			        float: left;
			        }
			div.inside .alignright {
			        width: 45%;
			        float: right;
			        text-align: right;
			        }
        </style>
	<?php }


}
